[![Build Status](https://travis-ci.org/RustyBower/sopel-quotes.svg?branch=master)](https://travis-ci.org/RustyBower/sopel-quotes)
[![Maintainability](https://api.codeclimate.com/v1/badges/e19bb5c6b49f968fedaf/maintainability)](https://codeclimate.com/github/RustyBower/sopel-quotes/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/e19bb5c6b49f968fedaf/test_coverage)](https://codeclimate.com/github/RustyBower/sopel-quotes/test_coverage)

# Sopel Quotes

Sopel Quotes is a module for handling user added IRC quotes

# Requirements

apt-get install libmysqlclient-dev
